@@ -4,7 +4,7 @@
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Copyright (C) 2014 - 2017                                             !
+   !    Copyright (C) 2014 - 2021                                             !
    !    The localCIDER development team (current and former contributors)     !
    !    Alex Holehouse, James Ahad, Rahul K. Das.                             !
    !                                                                          !
@@ -41,5 +41,5 @@
    import for data...
 
 """
-import aminoacids
-import highComplexitySequences
+from . import aminoacids
+from . import highComplexitySequences
